@@ -203,7 +203,12 @@ module Fluent
         @docker_hostname = nil
       end
       @ipaddr4 = ENV['IPADDR4'] || '127.0.0.1'
-      @ipaddr6 = ENV['IPADDR6'] || '::1'
+      @ipaddr6 = nil
+
+      if ENV['IPADDR6'] && ENV['IPADDR6'].length > 0
+        @ipaddr6 = ENV['IPADDR6']
+      end
+      
       @pipeline_version = (ENV['FLUENTD_VERSION'] || 'unknown fluentd version') + ' ' + (ENV['DATA_VERSION'] || 'unknown data version')
       # create the elasticsearch index name tag matchers
       unless @elasticsearch_index_names.empty?
@@ -280,7 +285,7 @@ module Fluent
       '8' => 'trace',
       '9' => 'unknown',
     }
-    def normalize_level(level, newlevel, stream=nil, priority=nil)
+    def normalize_level(level, newlevel, priority=nil)
       # if the record already has a level field, and it looks like one of our well
       # known values, convert it to the canonical normalized form - otherwise,
       # preserve the value in string format
@@ -290,10 +295,6 @@ module Fluent
                (level.respond_to?(:downcase) && (retlevel = NORMAL_LEVELS[level.downcase]))
           retlevel = level.to_s # don't know what it is - just convert to string
         end
-      elsif stream == 'stdout'
-        retlevel = 'info'
-      elsif stream == 'stderr'
-        retlevel = 'err'
       elsif !priority.nil?
         retlevel = PRIORITY_LEVELS[priority]
       else
@@ -321,7 +322,7 @@ module Fluent
 
     def process_k8s_json_file_fields(tag, time, record, fmtr_type = nil)
       record['message'] = record['message'] || record['log']
-      record['level'] = normalize_level(record['level'], nil, record['stream'])
+      record['level'] = normalize_level(record['level'], nil)
       if record.key?('kubernetes') && record['kubernetes'].respond_to?(:fetch) && \
          (k8shost = record['kubernetes'].fetch('host', nil))
         record['hostname'] = k8shost
@@ -371,7 +372,9 @@ module Fluent
       # this will catch the case where pipeline_type doesn't exist, or is not a Hash
       record['pipeline_metadata'][pipeline_type] = {} unless record['pipeline_metadata'][pipeline_type].respond_to?(:fetch)
       record['pipeline_metadata'][pipeline_type]['ipaddr4'] = @ipaddr4
-      record['pipeline_metadata'][pipeline_type]['ipaddr6'] = @ipaddr6
+      if @ipaddr6
+        record['pipeline_metadata'][pipeline_type]['ipaddr6'] = @ipaddr6
+      end
       record['pipeline_metadata'][pipeline_type]['inputname'] = 'fluent-plugin-systemd'
       record['pipeline_metadata'][pipeline_type]['name'] = 'fluentd'
       record['pipeline_metadata'][pipeline_type]['received_at'] = Time.now.utc.to_datetime.rfc3339(6)
